@@ -36,7 +36,7 @@
 
 static GList *entries = NULL;
 GList *current = NULL;
-static guchar *serialized;
+static gchar *serialized;
 static gint pos_to_restore;
 static gboolean newer_data = FALSE;
 static gchar *afname, *afcomment;
@@ -367,7 +367,7 @@ grg_entries_free (void)
 static void
 meta_print (gpointer data, gpointer user_data)
 {
-	static int i = 0;	//it's used only for one call of grg_entries_print; it works only if so
+	static int i = 0;	/*it's used only for one call of grg_entries_print; it works only if so*/
 	int j = GPOINTER_TO_UINT (user_data);
 	struct grg_entry *entry = (struct grg_entry *) data;
 	g_print ("   **********\n%d: %s\n   **********\n\n",
@@ -380,8 +380,8 @@ guint grg_entries_n_el (void);
 void
 grg_entries_print (gint ennum, gchar * enpage)
 {
-	gchar *utfenpage;
-	guint ulen;
+	gchar *utfenpage = NULL;
+	gsize ulen;
 	if (ennum < 0 && enpage == NULL)
 	{
 		g_list_foreach (entries, meta_print, GUINT_TO_POINTER (0));
@@ -390,7 +390,7 @@ grg_entries_print (gint ennum, gchar * enpage)
 	if (ennum > -1)
 	{
 		if (ennum > grg_entries_n_el () || ennum == 0)
-			report_err (_("Invalid entry number"), 0, 1, NULL);	//and quit
+			report_err (_("Invalid entry number"), 0, 1, NULL);	/*and quit*/
 		grg_entries_nth (ennum - 1);
 		meta_print (current->data, GUINT_TO_POINTER (ennum));
 		return;
@@ -442,11 +442,13 @@ meta_save (gpointer data, gpointer user_data)
 	{
 		struct grg_attachment *att =
 			(struct grg_attachment *) attlist->data;
-		guchar *origfile, *b64file, *append;
+        void * void_origfile;
+		gchar *origfile, *b64file, *append;
 
-		grg_get_content (att, (void **) &origfile, NULL);
-		b64file = grg_encode64 (origfile, att->filedim, NULL);
-		GRGFREE (origfile, att->filedim);
+		grg_get_content (att, &void_origfile, NULL);
+        origfile = (gchar*)void_origfile;
+		b64file = (gchar*)grg_encode64 ((guchar*)origfile, att->filedim, NULL);
+		GRGFREE (void_origfile, att->filedim);
 		append = g_strdup_printf (XML_ATT_FORMAT, attachments,
 					  att->filename, att->comment,
 					  b64file);
@@ -501,7 +503,7 @@ grg_entries_save (gchar * file, GRG_KEY key, GtkWidget * parent)
 
 	grg_wait_message_change_reason (wait, _("saving"));
 
-	err = grg_encrypt_file (gctx, key, file, serialized,
+	err = grg_encrypt_file (gctx, key, (guchar*)file, (guchar*)serialized,
 				strlen (serialized));
 
 	grg_wait_message_change_reason (wait, _("cleaning up"));
@@ -518,7 +520,7 @@ grg_entries_save (gchar * file, GRG_KEY key, GtkWidget * parent)
 	return GRG_OK;
 }
 
-//the letter denoting the field is the first of the tag text
+/*the letter denoting the field is the first of the tag text*/
 #define	VERS_FIELD		's'
 #define TITLE_FIELD		't'
 #define BODY_FIELD		'b'
@@ -574,7 +576,7 @@ compose_entry (GMarkupParseContext * context,
 	case ATTACH_FIELD:
 	{
 		guint dim;
-		gchar *decoded = grg_decode64 (text, text_len, &dim);
+		gchar *decoded = (gchar*)grg_decode64 ((guchar*)text, text_len, &dim);
 		grg_attach_content (decoded, dim, afname, afcomment);
 		GRGFREE (decoded, dim);
 		GRGAFREE (afname);
@@ -643,13 +645,19 @@ grg_entries_load_from_string (gchar * str, GtkWidget * parent, gboolean X)
  * Returns: 0 if OK; an error code otherwise (see libgringotts' docs)
  */
 gint
-grg_load_wrapper (guchar ** txt, GRG_KEY key, const gint fd,
+grg_load_wrapper (gchar ** txt, GRG_KEY key, const gint fd,
 		  const gchar * file)
 {
 	gint err;
-	gulong len = 0;
+	glong len = 0;
+    guchar *unsigned_txt;
 
-	err = grg_decrypt_file_direct (gctx, key, fd, txt, &len);
+    /* I'm doing this assignment in and out because one cannot guarantee that
+     * pointers of different types will be the same.
+     * */
+    unsigned_txt = (guchar*)*txt;
+	err = grg_decrypt_file_direct (gctx, key, fd, &unsigned_txt, &len);
+    *txt = (gchar*)unsigned_txt;
 
 	grg_prefs_update ();
 
@@ -711,7 +719,7 @@ glong
 grg_entries_find (gchar * needle, glong offset, gboolean only_current,
 		  gboolean case_sens)
 {
-	guchar *text = grg_entries_get_Body (), *start =
+	gchar *text = grg_entries_get_Body (), *start =
 		g_utf8_offset_to_pointer (text, offset), *occur;
 	glong result;
 
