@@ -25,6 +25,7 @@
 #include "grg_entries.h"
 #include "grg_defs.h"
 #include "grg_pix.h"
+#include "grg_widgets.h"
 
 enum
 {
@@ -58,7 +59,7 @@ create_model (void)
 	for (i = 0; i < max; i++, grg_entries_next ())
 	{
 		guint nat = grg_entries_n_att ();
-		guchar *snat =
+		gchar *snat =
 			(nat == 0) ? g_strdup ("-") : g_strdup_printf ("%d",
 								       nat);
 
@@ -117,7 +118,7 @@ add_columns (GtkTreeView * treeview)
 
 	gtk_tree_view_column_set_widget (column, img_att);
 	g_object_set (G_OBJECT (renderer), "xalign", (gfloat) 0.5, NULL);
-	//needed at least in GTK 2.0.6, anyways doing it seems stupid 2 me
+	/*needed at least in GTK 2.0.6, anyways doing it seems stupid 2 me*/
 	gtk_widget_show (img_att);
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_add_attribute (column, renderer, "text",
@@ -238,15 +239,17 @@ grg_list_run (void)
 	tbar = gtk_toolbar_new ();
 	gtk_toolbar_set_orientation (GTK_TOOLBAR (tbar),
 				     GTK_ORIENTATION_VERTICAL);
+#if 0
 	gtk_toolbar_set_icon_size (GTK_TOOLBAR (tbar),
 				   GTK_ICON_SIZE_LARGE_TOOLBAR);
-	bup = gtk_toolbar_insert_stock (GTK_TOOLBAR (tbar), GTK_STOCK_GO_UP,
-					_("Move up"), "",
+#endif
+	bup = grg_toolbar_insert_stock (GTK_TOOLBAR (tbar), GTK_STOCK_GO_UP,
+					_("Move up"),
 					(GtkSignalFunc) move_row,
 					GINT_TO_POINTER (TRUE), -1);
-	bdown = gtk_toolbar_insert_stock (GTK_TOOLBAR (tbar),
+	bdown = grg_toolbar_insert_stock (GTK_TOOLBAR (tbar),
 					  GTK_STOCK_GO_DOWN, _("Move down"),
-					  "", (GtkSignalFunc) move_row,
+					  (GtkSignalFunc) move_row,
 					  GINT_TO_POINTER (FALSE), -1);
 
 	hbox = gtk_hbox_new (FALSE, GRG_PAD);
