@@ -27,6 +27,7 @@
 #include "grg_defs.h"
 #include "grg_safe.h"
 #include "grg_entries_vis.h"
+#include "grg_widgets.h"
 
 #include <gdk/gdkkeysyms.h>
 
@@ -47,7 +48,7 @@
 		menu[number] = gtk_menu_item_new_with_mnemonic(txt); \
 		gtk_menu_shell_insert (GTK_MENU_SHELL (file), menu[number], 9+number); \
 		g_signal_connect (menu[number], "activate", G_CALLBACK(meta_load_file), text_copy); \
-		g_list_append (garbage, text_copy); \
+		garbage = g_list_append (garbage, text_copy); \
 		g_free(txt); g_free (ufile); \
 	}
 
@@ -106,18 +107,18 @@ grg_menu_create (GtkWidget * window)
 	wid = gtk_tearoff_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (file), wid);
 
-	NEW_MENU_ITEM (bnew, _("New"), do_new, NULL, file, GTK_STOCK_NEW,
+	NEW_MENU_ITEM (bnew, _("_New"), do_new, NULL, file, GTK_STOCK_NEW,
 		       GDK_N, GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (file);
-	NEW_MENU_ITEM (bopen, _("Open"), meta_load, NULL, file,
+	NEW_MENU_ITEM (bopen, _("_Open"), meta_load, NULL, file,
 		       GTK_STOCK_OPEN, GDK_O, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bsave, _("Save"), save, NULL, file, GTK_STOCK_SAVE,
+	NEW_MENU_ITEM (bsave, _("_Save"), save, NULL, file, GTK_STOCK_SAVE,
 		       GDK_S, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bsas, _("Save As"), meta_save_as, NULL, file,
+	NEW_MENU_ITEM (bsas, _("Save _As"), meta_save_as, NULL, file,
 		       GTK_STOCK_SAVE_AS, GDK_A, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (brev, _("Revert"), revert, NULL, file,
+	NEW_MENU_ITEM (brev, _("_Revert"), revert, NULL, file,
 		       GTK_STOCK_REVERT_TO_SAVED, GDK_R, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bclose, _("Close"), file_close, NULL, file,
+	NEW_MENU_ITEM (bclose, _("_Close"), file_close, NULL, file,
 		       GTK_STOCK_CLOSE, GDK_W, GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (file);
 	recent = grg_recent_dox;
@@ -128,11 +129,11 @@ grg_menu_create (GtkWidget * window)
 		i++;
 	}
 	NEW_MENU_SEPARATOR (file);
-	NEW_MENU_ITEM (bquit, _("Quit"), meta_quit, NULL, file,
+	NEW_MENU_ITEM (bquit, _("_Quit"), meta_quit, NULL, file,
 		       GTK_STOCK_QUIT, GDK_Q, GDK_CONTROL_MASK);
 
 
-	wid = gtk_menu_item_new_with_label (_("File"));
+	wid = gtk_menu_item_new_with_mnemonic (_("_File"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (wid), file);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar), wid);
 
@@ -150,27 +151,27 @@ grg_menu_create (GtkWidget * window)
 	NEW_MENU_ITEM (brem, _("Remove"), del, NULL, edit, GTK_STOCK_REMOVE,
 		       GDK_E, GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (edit);
-	NEW_MENU_ITEM (bcut, _("Cut"), cucopa, GINT_TO_POINTER (GRG_CUT),
+	NEW_MENU_ITEM (bcut, _("Cu_t"), cucopa, GINT_TO_POINTER (GRG_CUT),
 		       edit, GTK_STOCK_CUT, GDK_X, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bcop, _("Copy"), cucopa, GINT_TO_POINTER (GRG_COPY),
+	NEW_MENU_ITEM (bcop, _("_Copy"), cucopa, GINT_TO_POINTER (GRG_COPY),
 		       edit, GTK_STOCK_COPY, GDK_C, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bpaste, _("Paste"), cucopa,
+	NEW_MENU_ITEM (bpaste, _("_Paste"), cucopa,
 		       GINT_TO_POINTER (GRG_PASTE), edit, GTK_STOCK_PASTE,
 		       GDK_V, GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (edit);
-	NEW_MENU_ITEM (bfind, _("Find"), find, GINT_TO_POINTER (FALSE), edit,
+	NEW_MENU_ITEM (bfind, _("_Find"), find, GINT_TO_POINTER (FALSE), edit,
 		       GTK_STOCK_FIND, GDK_F, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bfinda, _("Find again"), find, GINT_TO_POINTER (TRUE),
+	NEW_MENU_ITEM (bfinda, _("Find a_gain"), find, GINT_TO_POINTER (TRUE),
 		       edit, GTK_STOCK_FIND, GDK_F3, 0);
 	NEW_MENU_SEPARATOR (edit);
-	NEW_MENU_ITEM (bpwd, _("Change Password"), chpwd, NULL, edit,
+	NEW_MENU_ITEM (bpwd, _("Change Pass_word"), chpwd, NULL, edit,
 		       GTK_STOCK_CONVERT, GDK_C,
 		       GDK_SHIFT_MASK | GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (edit);
-	NEW_MENU_ITEM (bpref, _("Preferences"), launch_prefs, NULL, edit,
+	NEW_MENU_ITEM (bpref, _("P_references"), launch_prefs, NULL, edit,
 		       GTK_STOCK_PREFERENCES, GDK_P, GDK_CONTROL_MASK);
 
-	wid = gtk_menu_item_new_with_label (_("Edit"));
+	wid = gtk_menu_item_new_with_mnemonic (_("_Edit"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (wid), edit);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar), wid);
 
@@ -183,25 +184,25 @@ grg_menu_create (GtkWidget * window)
 	wid = gtk_tearoff_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (nav), wid);
 
-	NEW_MENU_ITEM (bmfirst, _("First"), move_around,
+	NEW_MENU_ITEM (bmfirst, _("_First"), move_around,
 		       GINT_TO_POINTER (GRG_MV_FIRST), nav,
 		       GTK_STOCK_GOTO_FIRST, GDK_I, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bmback, _("Back"), move_around,
+	NEW_MENU_ITEM (bmback, _("_Back"), move_around,
 		       GINT_TO_POINTER (GRG_MV_PREV), nav, GTK_STOCK_GO_BACK,
 		       GDK_K, GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bmfor, _("Forward"), move_around,
+	NEW_MENU_ITEM (bmfor, _("For_ward"), move_around,
 		       GINT_TO_POINTER (GRG_MV_NEXT), nav,
 		       GTK_STOCK_GO_FORWARD, GDK_W,
 		       GDK_SHIFT_MASK | GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (bmlast, _("Last"), move_around,
+	NEW_MENU_ITEM (bmlast, _("_Last"), move_around,
 		       GINT_TO_POINTER (GRG_MV_LAST), nav,
 		       GTK_STOCK_GOTO_LAST, GDK_T, GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (nav);
-	NEW_MENU_ITEM (bmind, _("Index"), meta_list, NULL, nav,
+	NEW_MENU_ITEM (bmind, _("_Index"), meta_list, NULL, nav,
 		       GTK_STOCK_INDEX, GDK_X,
 		       GDK_SHIFT_MASK | GDK_CONTROL_MASK);
 
-	wid = gtk_menu_item_new_with_mnemonic (_("Navigation"));
+	wid = gtk_menu_item_new_with_mnemonic (_("_Navigation"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (wid), nav);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar), wid);
 
@@ -214,11 +215,11 @@ grg_menu_create (GtkWidget * window)
 	wid = gtk_tearoff_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (tools), wid);
 
-	NEW_MENU_ITEM (bwipe, _("Wipe file"), wipe_file, NULL, tools,
+	NEW_MENU_ITEM (bwipe, _("_Wipe file"), wipe_file, NULL, tools,
 		       GTK_STOCK_CLEAR, GDK_D,
 		       GDK_SHIFT_MASK | GDK_CONTROL_MASK);
 
-	wid = gtk_menu_item_new_with_mnemonic (_("Tools"));
+	wid = gtk_menu_item_new_with_mnemonic (_("_Tools"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (wid), tools);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar), wid);
 
@@ -231,19 +232,19 @@ grg_menu_create (GtkWidget * window)
 	wid = gtk_tearoff_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (help), wid);
 
-	NEW_MENU_ITEM (babo, _("Security monitor"), grg_security_monitor,
+	NEW_MENU_ITEM (babo, _("_Security monitor"), grg_security_monitor,
 		       NULL, help, GTK_STOCK_HELP, GDK_S,
 		       GDK_SHIFT_MASK | GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (help);
-	NEW_MENU_ITEM (babo, "README", readme, NULL, help, GTK_STOCK_HELP,
+	NEW_MENU_ITEM (babo, "_README", readme, NULL, help, GTK_STOCK_HELP,
 		       GDK_R, GDK_SHIFT_MASK | GDK_CONTROL_MASK);
-	NEW_MENU_ITEM (babo, "FAQ", faq, NULL, help, GTK_STOCK_HELP,
+	NEW_MENU_ITEM (babo, "_FAQ", faq, NULL, help, GTK_STOCK_HELP,
 		       GDK_F, GDK_SHIFT_MASK | GDK_CONTROL_MASK);
 	NEW_MENU_SEPARATOR (help);
-	NEW_MENU_ITEM (babo, _("About"), about, NULL, help, GTK_STOCK_HELP,
+	NEW_MENU_ITEM (babo, _("_About"), about, NULL, help, GTK_STOCK_HELP,
 		       GDK_B, GDK_CONTROL_MASK);
 
-	wid = gtk_menu_item_new_with_label (_("Help"));
+	wid = gtk_menu_item_new_with_mnemonic (_("_Help"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (wid), help);
 	gtk_menu_item_set_right_justified (GTK_MENU_ITEM (wid), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar), wid);
