@@ -21,6 +21,8 @@
 
 #include <stdio.h>
 #include <fcntl.h>
+#include <unistd.h>
+#include <stdlib.h>
 
 #include <glib.h>
 #include <popt.h>
@@ -29,6 +31,9 @@
 #include "gringotts.h"
 #include "grg_pwd.h"
 #include "grg_popt.h"
+#include "grg_safe.h"
+#include "grg_entries.h"
+#include "grg_widgets.h"
 
 #include <libgringotts.h>
 
@@ -42,7 +47,7 @@ dump_content (gchar * fname, gint ennum, gchar * enpage)
 	GRG_KEY key;
 	glong len;
 	gint err, fd;
-	guchar *txt;
+	gchar *txt;
 
 #ifndef HAVE_TCGETATTR
 	fprintf (stderr, "%s: %s\n", _("Warning"),
@@ -114,7 +119,11 @@ dump_content (gchar * fname, gint ennum, gchar * enpage)
 			continue;
 		}
 
-		err = grg_decrypt_file_direct (gctx, key, fd, &txt, &len);
+        {
+            guchar *unsigned_txt;
+		    err = grg_decrypt_file_direct (gctx, key, fd, &unsigned_txt, &len);
+            txt = (gchar*)unsigned_txt;
+        }
 
 		grg_key_free (gctx, key);
 
@@ -143,7 +152,7 @@ dump_content (gchar * fname, gint ennum, gchar * enpage)
 				    ("Problem with libmcrypt, probably a faulty installation"),
 				    0, 1, NULL);
 
-		//just to be sure...
+		/*just to be sure... */
 		default:
 			if (err < 0)
 				report_err (_("Gringotts internal error. Cannot finish operation."),
@@ -253,9 +262,9 @@ grg_parse_argv (gint argc, gchar * argv[], gchar ** filename,
 		return;
 	}
 
-//wipe and dump operations are processed without returning to main()
+/*wipe and dump operations are processed without returning to main() */
 
-//FIXME this should be in grg_safe.c
+/*FIXME this should be in grg_safe.c */
 #ifdef HAVE_ISATTY
 	if (!isatty (STDIN))
 	{
