@@ -28,6 +28,7 @@
 #include "grg_prefs_io.h"
 #include "gringotts.h"
 #include "grg_widgets.h"
+#include "grg_prefs.h"
 
 #define NEW_RADIO_BUTTON(widget, list, call, value, label, box) \
 	widget = gtk_radio_button_new_with_label(list, label); \
@@ -59,13 +60,14 @@ static GtkWidget *rij1_but, *ser_but, *twof_but, *cast_but, *safer_but;
 static GtkWidget *rij2_but, *tdes_but, *loki_but, *sha_but, *ripe_but;
 static GtkWidget *zlib_but, *bz_but, *r0_but, *r3_but, *r6_but, *r9_but;
 static GtkWidget *crypto_key_lbl, *crypto_block_lbl;
-static GtkWidget *bak_check, *over_check, *splash_check, *xpire_check;
+static GtkWidget *bak_check, *over_check, *splash_check, *tray_check, *xpire_check;
 static GtkWidget *xpire_spin, *passes_spin, *but_font;
 static GtkWidget *cclip_check, *qclip_check;
 
 gboolean grg_prefs_warn4overwrite = TRUE;
 gboolean grg_prefs_bak_files = TRUE;
 gboolean grg_prefs_splash = TRUE;
+gboolean grg_prefs_tray = TRUE;
 gboolean grg_prefs_clip_clear_on_close = FALSE;
 gboolean grg_prefs_clip_clear_on_quit = TRUE;
 gint grg_prefs_xpire = EXP_TIME_DEF;	/*abs(x)= num of days; < 0 = never */
@@ -162,18 +164,34 @@ static void
 apply_values (void)
 {
 	gchar *utf;
-	grg_ctx_set_crypt_algo (gctx, tmp_pref_crypto);
-	grg_ctx_set_hash_algo (gctx, tmp_pref_hash);
-	grg_ctx_set_comp_algo (gctx, tmp_pref_comp);
-	grg_ctx_set_comp_ratio (gctx, tmp_pref_ratio);
-	g_free (grg_pref_file);
-	grg_pref_file =
-		g_strdup (gtk_entry_get_text (GTK_ENTRY (file_entry)));
+	gboolean dirty = FALSE;
+
+	if (grg_ctx_get_crypt_algo(gctx) != tmp_pref_crypto)
+	{
+		dirty = TRUE;
+		grg_ctx_set_crypt_algo (gctx, tmp_pref_crypto);
+	}
+	if (grg_ctx_get_hash_algo(gctx) != tmp_pref_hash)
+	{
+		dirty = TRUE;
+		grg_ctx_set_hash_algo (gctx, tmp_pref_hash);
+	}
+	if (grg_ctx_get_comp_algo(gctx) != tmp_pref_comp)
+	{
+		dirty = TRUE;
+		grg_ctx_set_comp_algo (gctx, tmp_pref_comp);
+	}
+	if (grg_ctx_get_comp_ratio(gctx) != tmp_pref_ratio)
+	{
+		dirty = TRUE;
+		grg_ctx_set_comp_ratio (gctx, tmp_pref_ratio);
+	}
+
+	set_pref_file (gtk_entry_get_text (GTK_ENTRY (file_entry)));
 	utf = g_filename_from_utf8 (grg_pref_file, -1, NULL, NULL, NULL);
 	if (!g_file_test (utf, G_FILE_TEST_IS_REGULAR))
 	{
-		g_free (grg_pref_file);
-		grg_pref_file = NULL;
+		grg_prefs_free ();
 		gtk_entry_set_text (GTK_ENTRY (file_entry), "");
 	}
 	g_free (utf);
@@ -184,7 +202,10 @@ apply_values (void)
 				(gtk_bin_get_child (GTK_BIN (but_font))))));
 	set_editor_font (grg_prefs_editor_font);
 
-	update_saveable (GRG_SAVE_ACTIVE);
+	if (dirty)
+		update_saveable (GRG_SAVE_ACTIVE);
+
+	/* unconditionally save prefs */
 	grg_save_prefs ();
 }
 
@@ -270,6 +291,13 @@ modify_splash (GtkWidget * data, gpointer value)
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data));
 }
 
+static void
+modify_tray (GtkWidget * data, gpointer value)
+{
+	grg_prefs_tray =
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data));
+}
+
 static void
 modify_cclip (GtkWidget * data, gpointer value)
 {
@@ -409,7 +437,6 @@ grg_pref_dialog (GtkWidget * parent)
 	GtkWidget *frame_xpire, *box_xpire, *xpire_lbl;
 	GtkWidget *frame_passes, *box_passes, *lbl_passes;
 	GtkWidget *frame_clip, *box_clip;
-	gint response;
 
 	PangoFontDescription *fdesc;
 
@@ -419,11 +446,10 @@ grg_pref_dialog (GtkWidget * parent)
 	prefs = gtk_dialog_new_with_buttons (_("Preferences"),
 					     GTK_WINDOW (parent),
 					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					     GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 					     GTK_STOCK_OK, GTK_RESPONSE_OK,
-					     GTK_STOCK_APPLY,
-					     GTK_RESPONSE_APPLY,
-					     GTK_STOCK_CANCEL,
-					     GTK_RESPONSE_CANCEL, NULL);
+					     NULL);
 
 	/*first page: algorithms */
 	tab1 = gtk_table_new (3, 2, FALSE);
@@ -555,6 +581,14 @@ grg_pref_dialog (GtkWidget * parent)
 			  G_CALLBACK (modify_splash), NULL);
 	gtk_box_pack_start (GTK_BOX (box_misc), splash_check, FALSE, TRUE, 1);
 
+
+	NEW_ROW_SEPARATOR (tab2);
+
+	tray_check = gtk_check_button_new_with_label (_("Tray-Icon (Needs Gringotts restart to take affect)"));
+	g_signal_connect (G_OBJECT (tray_check), "toggled",
+			G_CALLBACK (modify_tray), NULL);
+	gtk_box_pack_start (GTK_BOX (box_misc), tray_check, FALSE, TRUE, 1);
+
 	frame_file = gtk_frame_new (_("File to open at startup"));
 	gtk_box_pack_start (GTK_BOX (tab2), frame_file, FALSE, TRUE, 1);
 
@@ -669,7 +703,7 @@ grg_pref_dialog (GtkWidget * parent)
 	while (TRUE)
 	{
 		gboolean exit = TRUE;
-		response = gtk_dialog_run (GTK_DIALOG (prefs));
+		gint response = gtk_dialog_run (GTK_DIALOG (prefs));
 
 		switch (response)
 		{
@@ -680,7 +714,6 @@ grg_pref_dialog (GtkWidget * parent)
 			apply_values ();
 			exit = FALSE;
 			break;
-		case GTK_RESPONSE_CANCEL:
 		default:
 			break;
 		}
@@ -810,6 +843,8 @@ update_buttons (void)
 				      grg_prefs_warn4overwrite);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (splash_check),
 				      grg_prefs_splash);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tray_check),
+					grg_prefs_tray);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cclip_check),
 				      grg_prefs_clip_clear_on_close);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (qclip_check),
