@@ -453,7 +453,6 @@ meta_quit (void)
 	if (file_close () == GRG_CANCEL)
 		return;
 
-	/* TODO: see mainwin_resize() */
 	grg_save_prefs();
 
 	quit (0);
@@ -726,11 +725,12 @@ load_file (gchar * input_filename)
 	while (TRUE)
 	{
 		gboolean doret = FALSE, exit = FALSE;
+		gboolean cancelled = FALSE;
 		gchar *msg = NULL;
 
-		tmpkey = grg_ask_pwd_dialog (win1);
+		tmpkey = grg_ask_pwd_dialog (win1, &cancelled);
 
-		if (!tmpkey)
+		if (!tmpkey || cancelled)
 		{
 			close (fd);
 			goto cleanup;
@@ -935,16 +935,18 @@ void
 do_new (void)
 {
 	GRG_KEY tmpkey;
+	gboolean cancelled = FALSE;
 
 	if (file_close () == GRG_CANCEL)
 		return;
 
 	g_assert (GTK_IS_WIDGET (win1));
 
-	tmpkey = grg_new_pwd_dialog (GTK_WIDGET (win1));
+	tmpkey = grg_new_pwd_dialog (GTK_WIDGET (win1), &cancelled);
 
 	if (!tmpkey)
 	{
+		if (!cancelled)
 		grg_msg (_("You must enter a valid password!"),
 			 GTK_MESSAGE_ERROR, win1);
 		return;
@@ -1235,8 +1237,12 @@ void
 chpwd (void)
 {
 	GRG_KEY tmpkey, verkey;
+	gboolean cancelled = FALSE;
 
-	verkey = grg_ask_pwd_dialog (win1);
+	verkey = grg_ask_pwd_dialog (win1, &cancelled);
+
+	if (cancelled)
+		return;
 
 	if (!verkey || !grg_key_compare (verkey, key))
     {
@@ -1252,7 +1258,7 @@ chpwd (void)
 	grg_key_free (gctx, verkey);
 	verkey = NULL;
 
-	tmpkey = grg_new_pwd_dialog (win1);
+	tmpkey = grg_new_pwd_dialog (win1, NULL);
 
 	if (tmpkey)
 	{
@@ -1517,10 +1523,6 @@ mainwin_resize (GtkWidget *widget, GtkAllocation *allocation)
 
 	grg_prefs_mainwin_width = allocation->width;
 	grg_prefs_mainwin_height = allocation->height;
-	/* TODO: in theory, prefs saveable status should be updated with GRG_SET_ACTIVE here,
-	but because current prefs design doesn't make the difference between GUI-prefs
-	dirty status and open-file dirty status, grg_save_prefs() is unconditionally
-	called when leaving */
 }
 
 /**
@@ -1801,6 +1803,89 @@ grg_interface (void)
 
 	if (grg_prefs_splash)
 		gtk_widget_show_all (grg_splash (win1));
+
+}
+
+
+void tray_icon_on_click(GtkStatusIcon *status_icon, gpointer user_data)
+{
+	if(gdk_window_get_state(GTK_WIDGET(win1)->window)==1 ||gdk_window_get_state(GTK_WIDGET(win1)->window)==2) {
+		/* The window is either iconified, or on another workspace */
+		gtk_widget_show_all(win1);
+		gtk_window_deiconify(GTK_WINDOW(win1));
+	}else{  
+		gtk_widget_hide(win1);
+		gtk_status_icon_set_visible(GTK_STATUS_ICON(status_icon), TRUE);
+	}
+}
+
+void tray_button_view(GtkMenuItem *item, gpointer window)
+{
+	gtk_widget_show(GTK_WIDGET(window));
+	gtk_window_deiconify(GTK_WINDOW(window));
+}
+
+void tray_button_exit(GtkMenuItem *item, gpointer user_data)
+{
+	meta_quit();
+}
+
+void tray_button_about(GtkMenuItem *item, gpointer user_data)
+{
+	about();
+}
+
+void trayIconPopup(GtkStatusIcon *status_icon, guint button, guint32 activate_time, gpointer popUpMenu)
+{
+	gtk_menu_popup(GTK_MENU(popUpMenu), NULL, NULL, gtk_status_icon_position_menu, status_icon, button, activate_time);
+}
+
+/* Creates a GTK-Tray-icon: */
+GtkStatusIcon *create_tray_icon(void)
+{
+	GtkStatusIcon *tray_icon;
+
+	tray_icon = gtk_status_icon_new();
+	GdkPixbuf *gp = gdk_pixbuf_new_from_xpm_data (gringotts_xpm);
+	gtk_status_icon_set_from_pixbuf(tray_icon, gp);
+	gtk_status_icon_set_tooltip(tray_icon, "Gringotts");
+	gtk_status_icon_set_visible(tray_icon, TRUE);
+	g_object_unref (G_OBJECT (gp));
+
+	return tray_icon;
+}
+
+/* Initiates the Tray-icon: */
+void tray_icon_init(void)
+{
+	GtkWidget *menu, *menuItemView, *menuItemExit, *menuItemAbout, *menuItemSeparator;
+	GtkStatusIcon *tray_icon;
+
+	/* Tray-icon is created and shown */
+	tray_icon = create_tray_icon();
+
+	/* Right-click menu for trayicon */
+	menu = gtk_menu_new();
+	menuItemView = gtk_menu_item_new_with_label ("View");
+	menuItemAbout = gtk_image_menu_item_new_from_stock (GTK_STOCK_ABOUT,NULL);
+	menuItemExit = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT,NULL);
+	menuItemSeparator = gtk_separator_menu_item_new ();
+
+	/* Signal-handler for right-click menu */
+	g_signal_connect (G_OBJECT (menuItemView), "activate", G_CALLBACK (tray_button_view), win1);
+	g_signal_connect (G_OBJECT (menuItemExit), "activate", G_CALLBACK (tray_button_exit), NULL);
+	g_signal_connect (G_OBJECT (menuItemAbout), "activate", G_CALLBACK (tray_button_about), NULL);
+
+	/* Creates the actual right-click menu and shows it */
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuItemView);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuItemSeparator);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuItemAbout);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuItemExit);
+	gtk_widget_show_all (menu);
+
+	/* other signal-handler for left/right-click on the icon itself */
+	g_signal_connect(GTK_STATUS_ICON (tray_icon), "popup-menu", GTK_SIGNAL_FUNC (trayIconPopup), menu);
+	g_signal_connect(G_OBJECT(tray_icon), "activate", G_CALLBACK(tray_icon_on_click), NULL);
 }
 
 /**
@@ -1819,6 +1904,7 @@ main (gint argc, gchar ** argv)
 	guchar *version = grg_get_version (); /* libgringotts version */
 	gint prefs_err;
 	gboolean root = FALSE;
+	
 
 	if (!grg_mlockall_and_drop_root_privileges ())
 		exit (1);
@@ -1893,6 +1979,9 @@ main (gint argc, gchar ** argv)
 	}
 
 	gtk_loop_started = TRUE;
+
+	if (grg_prefs_tray)
+			tray_icon_init();
 	gtk_main ();
 
 	return 0;
