@@ -31,77 +31,80 @@ glong pwdbirth;
 
 	/*callbacks for menu items */
 
-//Displays a "not yet implemented" message box
-//void nyi(void);
+/* Displays a "not yet implemented" message box */
+/* void nyi(void); */
 
 	/*menu File */
 
-//Creates a new document.
+/* Creates a new document. */
 void do_new (void);
 
-//Displays a file loading dialog, then calls load.
+/* Displays a file loading dialog, then calls load. */
 void meta_load (void);
 
-//Calls load_file() with the specified file arg.
+/* Calls load_file() with the specified file arg. */
 void meta_load_file (gpointer callback_data, gchar * callback_action);
 
-//Saves the current version of the opened document.
+/* Saves the current version of the opened document. */
 void save (void);
 
-//Displays the Save As dialog, then calls save_as.
+/* Displays the Save As dialog, then calls save_as. */
 void meta_save_as (void);
 
-//Reverts to last saved version.
+/* Reverts to last saved version. */
 void revert (void);
 
-//Closes the opened document.
+/* Closes the opened document. */
 grg_response file_close (void);
 
-//exits
+/* exits */
 void quit (gint code);
 void emergency_quit (void);
 
-//Asks for save if not saved, and then exits.
+/* Asks for save if not saved, and then exits. */
 void meta_quit (void);
 
 void meta_saveable (gpointer data, gpointer user_data);
 
 	/*menu Edit */
 
-//Appends a new entry.
+/* Appends a new entry. */
 void insert (void);
 
-//Deletes the current entry.
+/* Deletes the current entry. */
 void del (void);
 
-//Calls the change password dialog.
+/* Calls the change password dialog. */
 void chpwd (void);
 
-//Displays the preferences window.
+/* Displays the preferences window. */
 void launch_prefs (void);
 
 	/*menu Navigation */
 
-//Displays the entry in the specified direction.
+/* Displays the entry in the specified direction. */
 void move_around (gpointer callback_data, guint callback_action);
 
-//Calls the list window.
+/* Calls the list window. */
 void meta_list (void);
 
 	/*menu Tools */
 
-//Securely wipe a file
+/* Securely wipe a file */
 void wipe_file (void);
 
 	/*menu Help */
 
-//Displays the `About' box.
+/* Displays the `About' box. */
 void about (void);
 
-//Performs an action about saveability.
-gboolean update_saveable (gint mode);
+/* Performs an action about saveability. */
+gboolean update_saveable (grg_saveable mode);
 
-guchar *get_editor_font (void);
-void set_editor_font (const guchar * font_desc);
+gchar *get_editor_font (void);
+void set_editor_font (const gchar * font_desc);
+
+void update (void);
+extern const char *gringotts_xpm[115];
 
 #endif
